@@ -26,7 +26,7 @@
 #include "RoseXmlHandler.h"
 
 #include "sound/Midi.h"
-#include <klocale.h>
+#include <tdelocale.h>
 #include "misc/Debug.h"
 #include "misc/Strings.h"
 #include "base/AudioLevel.h"
@@ -52,15 +52,15 @@
 #include "gui/application/RosegardenApplication.h"
 #include "gui/dialogs/FileLocateDialog.h"
 #include "gui/general/ProgressReporter.h"
-#include "gui/kdeext/KStartupLogo.h"
+#include "gui/kdeext/TDEStartupLogo.h"
 #include "gui/studio/AudioPlugin.h"
 #include "gui/studio/AudioPluginManager.h"
 #include "gui/widgets/CurrentProgressDialog.h"
 #include "gui/widgets/ProgressDialog.h"
 #include "RosegardenGUIDoc.h"
 #include "sound/AudioFileManager.h"
-#include <kfiledialog.h>
-#include <kmessagebox.h>
+#include <tdefiledialog.h>
+#include <tdemessagebox.h>
 #include <tqcstring.h>
 #include <tqdatastream.h>
 #include <tqdialog.h>
@@ -447,7 +447,7 @@ RoseXmlHandler::startElement(const TQString& namespaceURI,
                     minor > RosegardenGUIDoc::FILE_FORMAT_VERSION_MINOR) {
 
                 CurrentProgressDialog::freeze();
-                KStartupLogo::hideIfStillThere();
+                TDEStartupLogo::hideIfStillThere();
 
                 KMessageBox::information(0, i18n("This file was written by Rosegarden %1, which is more recent than this version.\nThere may be some incompatibilities with the file format.").arg(version));
 
@@ -1032,7 +1032,7 @@ RoseXmlHandler::startElement(const TQString& namespaceURI,
                 CurrentProgressDialog::freeze();
 
                 // Hide splash screen if present on startup
-                KStartupLogo::hideIfStillThere();
+                TDEStartupLogo::hideIfStillThere();
 
                 // Create a locate file dialog - give it the file name
                 // and the AudioFileManager path that we've already
@@ -2250,7 +2250,7 @@ RoseXmlHandler::addMIDIDevice(TQString name, bool createAtSequencer)
         arg << (unsigned int)MidiDevice::Play;
 
         if (!rgapp->sequencerCall("addDevice(int, unsigned int)", replyType, replyData, data)) {
-            SETQMAN_DEBUG << "RoseXmlHandler::addMIDIDevice - "
+            SEQMAN_DEBUG << "RoseXmlHandler::addMIDIDevice - "
             << "can't call sequencer addDevice" << endl;
             return ;
         }
@@ -2259,18 +2259,18 @@ RoseXmlHandler::addMIDIDevice(TQString name, bool createAtSequencer)
             TQDataStream reply(replyData, IO_ReadOnly);
             reply >> deviceId;
         } else {
-            SETQMAN_DEBUG << "RoseXmlHandler::addMIDIDevice - "
+            SEQMAN_DEBUG << "RoseXmlHandler::addMIDIDevice - "
             << "got unknown returntype from addDevice()" << endl;
             return ;
         }
 
         if (deviceId == Device::NO_DEVICE) {
-            SETQMAN_DEBUG << "RoseXmlHandler::addMIDIDevice - "
+            SEQMAN_DEBUG << "RoseXmlHandler::addMIDIDevice - "
             << "sequencer addDevice failed" << endl;
             return ;
         }
 
-        SETQMAN_DEBUG << "RoseXmlHandler::addMIDIDevice - "
+        SEQMAN_DEBUG << "RoseXmlHandler::addMIDIDevice - "
         << " added device " << deviceId << endl;
 
     } else {
@@ -2298,7 +2298,7 @@ RoseXmlHandler::addMIDIDevice(TQString name, bool createAtSequencer)
 void
 RoseXmlHandler::skipToNextPlayDevice()
 {
-    SETQMAN_DEBUG << "RoseXmlHandler::skipToNextPlayDevice; m_deviceRunningId is " << m_deviceRunningId << endl;
+    SEQMAN_DEBUG << "RoseXmlHandler::skipToNextPlayDevice; m_deviceRunningId is " << m_deviceRunningId << endl;
 
     for (DeviceList::iterator i = getStudio().getDevices()->begin();
             i != getStudio().getDevices()->end(); ++i) {
@@ -2310,7 +2310,7 @@ RoseXmlHandler::skipToNextPlayDevice()
             if (m_deviceRunningId == Device::NO_DEVICE ||
                     md->getId() > m_deviceRunningId) {
 
-                SETQMAN_DEBUG << "RoseXmlHandler::skipToNextPlayDevice: found next device: id " << md->getId() << endl;
+                SEQMAN_DEBUG << "RoseXmlHandler::skipToNextPlayDevice: found next device: id " << md->getId() << endl;
 
                 m_device = md;
                 m_deviceRunningId = md->getId();
@@ -2319,7 +2319,7 @@ RoseXmlHandler::skipToNextPlayDevice()
         }
     }
 
-    SETQMAN_DEBUG << "RoseXmlHandler::skipToNextPlayDevice: fresh out of devices" << endl;
+    SEQMAN_DEBUG << "RoseXmlHandler::skipToNextPlayDevice: fresh out of devices" << endl;
 
     m_device = 0;
 }
@@ -2327,7 +2327,7 @@ RoseXmlHandler::skipToNextPlayDevice()
 void
 RoseXmlHandler::setMIDIDeviceConnection(TQString connection)
 {
-    SETQMAN_DEBUG << "RoseXmlHandler::setMIDIDeviceConnection(" << connection << ")" << endl;
+    SEQMAN_DEBUG << "RoseXmlHandler::setMIDIDeviceConnection(" << connection << ")" << endl;
 
     MidiDevice *md = dynamic_cast<MidiDevice *>(m_device);
     if (!md)
@@ -2347,7 +2347,7 @@ RoseXmlHandler::setMIDIDeviceConnection(TQString connection)
 void
 RoseXmlHandler::setMIDIDeviceName(TQString name)
 {
-    SETQMAN_DEBUG << "RoseXmlHandler::setMIDIDeviceName(" << name << ")" << endl;
+    SEQMAN_DEBUG << "RoseXmlHandler::setMIDIDeviceName(" << name << ")" << endl;
 
     MidiDevice *md = dynamic_cast<MidiDevice *>(m_device);
     if (!md)
