@@ -77,7 +77,7 @@ static const int MERGE_KEEP_NEW_TIMINGS = (1 << 3);
   * The RosegardenGUIDoc class provides a document object that can be
   * used in conjunction with the classes RosegardenGUIApp and
   * RosegardenGUIView to create a document-view model for standard KDE
-  * applications based on KApplication and KTMainWindow. Thereby, the
+  * applications based on TDEApplication and KTMainWindow. Thereby, the
   * document object is created by the RosegardenGUIApp instance and
   * contains the document structure with the according methods for
   * manipulation of the document data by RosegardenGUIView
@@ -90,7 +90,7 @@ static const int MERGE_KEEP_NEW_TIMINGS = (1 << 3);
 class RosegardenGUIDoc : public TQObject
 {
     Q_OBJECT
-  TQ_OBJECT
+  
 public:
 
     /**
