@@ -25,10 +25,10 @@
 
 #include "TrackEditor.h"
 #include <tqlayout.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
 
-#include <klocale.h>
-#include <kconfig.h>
+#include <tdelocale.h>
+#include <tdeconfig.h>
 #include <kstddirs.h>
 #include "misc/Debug.h"
 #include "document/ConfigGroups.h"
@@ -62,8 +62,8 @@
 #include "TrackEditorIface.h"
 #include <dcopobject.h>
 #include <kcommand.h>
-#include <kglobal.h>
-#include <kmessagebox.h>
+#include <tdeglobal.h>
+#include <tdemessagebox.h>
 #include <tqapplication.h>
 #include <tqcursor.h>
 #include <tqfont.h>
@@ -174,7 +174,7 @@ TrackEditor::init(TQWidget* rosegardenguiview)
     kapp->config()->setGroup(GeneralOptionsConfigGroup);
     if (kapp->config()->readBoolEntry("backgroundtextures", true)) {
         TQPixmap background;
-        TQString pixmapDir = KGlobal::dirs()->findResource("appdata", "pixmaps/");
+        TQString pixmapDir = TDEGlobal::dirs()->findResource("appdata", "pixmaps/");
         if (background.load(TQString("%1/misc/bg-segmentcanvas.xpm").
                             arg(pixmapDir))) {
             m_segmentCanvas->setBackgroundPixmap(background);
