@@ -25,9 +25,9 @@
 
 #include "QuantizeParameters.h"
 #include <tqlayout.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include "base/NotationTypes.h"
 #include "base/Quantizer.h"
 #include "base/BasicQuantizer.h"
@@ -36,7 +36,7 @@
 #include "gui/editors/notation/NotationStrings.h"
 #include "gui/editors/notation/NotePixmapFactory.h"
 #include <kcombobox.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
 #include <tqcheckbox.h>
 #include <tqframe.h>
 #include <tqgroupbox.h>
@@ -218,7 +218,7 @@ QuantizeParameters::QuantizeParameters(TQWidget *parent,
     int defaultIterate = 100;
 
     if (!m_configCategory.isNull()) {
-        KConfig *config = kapp->config();
+        TDEConfig *config = kapp->config();
         config->setGroup(m_configCategory);
         defaultType =
             config->readNumEntry("quantizetype",
@@ -413,7 +413,7 @@ QuantizeParameters::getQuantizer() const
     }
 
     if (!m_configCategory.isNull()) {
-        KConfig *config = kapp->config();
+        TDEConfig *config = kapp->config();
         config->setGroup(m_configCategory);
         config->writeEntry("quantizetype", type);
         config->writeEntry("quantizeunit", unit);
